ColReorder examples - Integration

# ColReorder example Integration

The examples in this section demonstrate ColReorder being used with other DataTables extensions.

### Integration with other DataTables extensions

- Column visibility integration
- FixedColumns integration
- FixedHeader integration
- Responsive integration
- Server-side processing
- State saving

Please refer to the DataTables documentation for full information about its API properties and methods.
Additionally, there are a wide range of extensions and plug-ins which extend the capabilities of DataTables.

DataTables designed and created by SpryMedia Ltd © 2007-2017
DataTables is licensed under the MIT license.